@@ -1,9 +1,11 @@
+# -*- coding: utf-8 -*-
+
 from pytest import raises
 from sqlalchemy_i18n import UnknownLocaleError
-from tests import TestCase
+from tests import DeclarativeTestCase, ClassicTestCase
 
 
-class TestTranslationComparator(TestCase):
+class Suite(object):
     def test_attribute_accessor_for_unknown_locale(self):
         with raises(UnknownLocaleError):
             assert self.Article.translations.some_unknown_locale
@@ -11,3 +13,11 @@ class TestTranslationComparator(TestCase):
     def test_attribute_accessors(self):
         assert self.Article.translations.en
         assert self.Article.translations.fi
+
+
+class TestDeclarative(Suite, DeclarativeTestCase):
+    pass
+
+
+class TestClassic(Suite, ClassicTestCase):
+    pass
